Properties Methods Events Direct Link

# Class Ext.calendar.EventEditWindow

Package: | Ext.calendar
Defined In: | EventEditWindow.js
Class: | EventEditWindow
Extends: | Object

A custom window containing a basic edit form used for quick editing of events.

This window also provides custom events specific to the calendar so that other calendar components can be easily notified when an event has been edited via this component.

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| EventEditWindow( `Object config` ) Parameters: `config` : Object The config object Returns: void | EventEditWindow
| show( `Ext.data.Record/Object o`, [`String/Element animateTarget`] ) : Ext.Window Shows the window, rendering it first if necessary, or activates it and brings it to front if hidden. Shows the window, rendering it first if necessary, or activates it and brings it to front if hidden. Parameters: `o` : Ext.data.Record/Object Either a Ext.data.Record if showing the form for an existing event in edit mode, or a plain object containing a StartDate property (and optionally an EndDate property) for showing the form in add mode. `animateTarget` : String/Element (optional) The target element or id from which the window should animate while opening (defaults to null with no animation) Returns: `Ext.Window` this | EventEditWindow

## Public Events

Event | Defined By
--- | ---
| editdetails : ( `Ext.calendar.EventEditWindow this`, `Ext.calendar.EventRecord rec` ) Fires when the user selects the option in this window to continue editing in the detailed edit form (by default, an i... Fires when the user selects the option in this window to continue editing in the detailed edit form (by default, an instance of Ext.calendar.EventEditForm. Handling code should hide this window and transfer the current event record to the appropriate instance of the detailed form by showing it and calling loadRecord. Listeners will be called with the following arguments: `this` : Ext.calendar.EventEditWindow `rec` : Ext.calendar.EventRecord The record that is currently being edited | EventEditWindow
| eventadd : ( `Ext.calendar.EventEditWindow this`, `Ext.calendar.EventRecord rec` ) Fires after a new event is added Fires after a new event is added Listeners will be called with the following arguments: `this` : Ext.calendar.EventEditWindow `rec` : Ext.calendar.EventRecord The new record that was added | EventEditWindow
| eventcancel : ( `Ext.calendar.EventEditWindow this`, `Ext.calendar.EventRecord rec` ) Fires after an event add/edit operation is canceled by the user and no store update took place Fires after an event add/edit operation is canceled by the user and no store update took place Listeners will be called with the following arguments: `this` : Ext.calendar.EventEditWindow `rec` : Ext.calendar.EventRecord The new record that was canceled | EventEditWindow
| eventdelete : ( `Ext.calendar.EventEditWindow this`, `Ext.calendar.EventRecord rec` ) Fires after an event is deleted Fires after an event is deleted Listeners will be called with the following arguments: `this` : Ext.calendar.EventEditWindow `rec` : Ext.calendar.EventRecord The new record that was deleted | EventEditWindow
| eventupdate : ( `Ext.calendar.EventEditWindow this`, `Ext.calendar.EventRecord rec` ) Fires after an existing event is updated Fires after an existing event is updated Listeners will be called with the following arguments: `this` : Ext.calendar.EventEditWindow `rec` : Ext.calendar.EventRecord The new record that was updated | EventEditWindow